<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use App\Models\Cities;
use App\Models\Location;

class LocationController extends Controller
{
    /**
     * All Locations
     */
    public function index() {
        $locations = Location::all();
        $cities = Cities::all();
        return view('admin.locations.AllLocations',['locations' => $locations, 'cities' => $cities]);
    }

    /**
     * Location create form
     */
    public function create() {
        $cities = Cities::all();
        return view('admin.locations.addlocation',['cities' => $cities]);
    }

    /**
     * Handle an incoming Location data request.
     *
     */
    public function store(Request $request): RedirectResponse
    {
        $request->validate([
            'city' => ['required', 'integer'],
            'location' => ['required', 'string'],
            'zip' => ['required', 'string'],
        ]);

        Location::create([
            'city' => $request->city,
            'location' => $request->location,
            'zip' => $request->zip,
            'price' => $request->price,
            'status' => $request->status ? $request->status : 'disable',
        ]);

        return redirect()->back()->with('success', 'Location added Successfully.');
    }

    /**
     * Display the Edit View
     */
    public function edit($id) {

        $location = Location::findOrFail($id);
        $cities = Cities::all();

        if(!$location) {
            return redirect()->route('admin.locations')->with('error', 'Location not found.');
        }

        return view('admin.locations.EditLocation',['location' => $location, 'cities' => $cities]);
    }

    /**
     * Update location
     */
    public function update(Request $request, $id) {

        $location = Location::findOrFail($id);

        if(!$location) {
            return redirect()->route('admin.locations')->with('error', 'Location not found.');
        }

        $request->validate([
            'city' => ['required', 'integer'],
            'location' => ['required', 'string'],
            'zip' => ['required', 'string'],
        ]);

        $location->update([
            'city' => $request->city,
            'location' => $request->location,
            'zip' => $request->zip,
            'price' => $request->price,
            'status' => $request->status ? $request->status : 'disable',
        ]);

        return redirect()->back()->with('success', 'Location updated Successfully.');
    }

    /**
     * Delete the location.
     */
    public function delete($id) {
        $location = Location::findOrFail($id);

        if(!$location) {
            return redirect()->route('admin.cities')->with('error', 'Location not found.');
        }

        $location->delete();
        return redirect()->back()->with('success', 'Location deleted Successfully.');
    }
}
