<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;

use App\Models\State;

class StateController extends Controller
{
    /**
     * All States
     */
    public function index() {
        $states = State::all();
        return view('admin.states.AllStates',['states' => $states]);
    }

    /**
     * State create form
     */
    public function create() {
        return view('admin.states.AddState');
    }

    /**
     * Handle an incoming State data request.
     *
     */
    public function store(Request $request): RedirectResponse
    {
        $request->validate([
            'state_name' => ['required', 'string']
        ]);

        State::create([
            'state_name' => $request->state_name,
            'state_code' => $request->state_code,
            'status' => $request->status ? $request->status : 'disable',
        ]);

        return redirect()->back()->with('success', 'State added Successfully.');
    }

    /**
     * Display the Edit View
     */
    public function edit($id) {

        $state = State::findOrFail($id);

        if(!$state) {
            return redirect()->route('admin.cities')->with('error', 'State not found.');
        }

        return view('admin.states.EditState',['state' => $state]);
    }

    /**
     * Update State
     */
    public function update(Request $request, $id) {

        $state = State::findOrFail($id);

        if(!$state) {
            return redirect()->route('admin.states')->with('error', 'State not found.');
        }

        $request->validate([
            'state_name' => ['required', 'string'],
        ]);

        $state->update([
            'state_name' => $request->state_name,
            'state_code' => $request->state_code,
            'status' => $request->status ? $request->status : 'disable',
        ]);

        return redirect()->back()->with('success', 'State updated Successfully.');
    }

    /**
     * Delete the State.
     */
    public function delete($id) {
        $state = State::findOrFail($id);

        if(!$state) {
            return redirect()->route('admin.states')->with('error', 'State not found.');
        }

        $state->delete();
        return redirect()->back()->with('success', 'State deleted Successfully.');
    }
}
