@extends('layouts.master')

@section('title', 'Cities')

@section('content')
    <section class="content">
        <div class="container-fluid">
            <a href="{{ route('admin.city.add') }}" class="btn btn-success mb-3">
                <i class="fas fa-plus"></i> Add City
            </a>
            @if(Session::has('error'))
                <div class="alert alert-danger">
                    {{ Session::get('error') }}
                </div>
            @endif
            @if(Session::has('success'))
                <div class="alert alert-success">
                    {{ Session::get('success') }}
                </div>
            @endif
            <table id="cityList" class="table table-striped table-bordered table-hover display dataTable no-footer dtr-inline">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Name</th>
                        <th>State</th>
                        <th></th>
                        <th></th>
                    </tr>
                </thead>
                <tbody>
                    @if($cities)
                    @foreach($cities as $city)
                    <tr>
                        <td>{{ $city->id }}</td>
                        <td><span data-city="{{ $city->id }}" class="show-loc">{{ $city->name }} <i class="fas fa-plus bg-success ml-1 p-1"></i> <i class="fas fa-spinner fa-spin invisible"></i></span></td>
                        <td>
                            @php
                            foreach ($states as $state) {
                                if ($state->id == $city->state) {
                                    echo $state['state_name'];
                                    break;
                                }
                            }
                            @endphp
                        </td>
                        <td><span class="btn {{ $city->status == 'enable' ? 'btn-success' : 'btn-danger' }}">{{ ucfirst($city->status) }}</span></td>
                        <td>
                            <a href="{{ route('admin.city.edit',$city->id) }}" class="btn btn-success"><i class="fas fa-edit"></i></a>
                            <a href="{{ route('admin.city.delete',$city->id) }}" class="btn btn-danger delete-city"><i class="fas fa-times"></i></a>
                        </td>
                    </tr>

                    @endforeach
                    @endif
                </tbody>
            </table>
        </div>
    </section>
@endsection

@section('pageJS')
<!-- Page Tables specific script -->
<script>
$(function () {
    if($('#cityList').length > 0) {
        $('#cityList').DataTable({
        "paging": true,
        "lengthChange": false,
        "searching": false,
        "ordering": true,
        "info": true,
        "autoWidth": false,
        "responsive": true,
        });
    }

    $(".delete-city").on("click",function(e){
        var confirmed = confirm("Are you sure you want to location?");
        if (!confirmed) {
            e.preventDefault();
        }
    })

    $(document).on("click",".show-loc",function(){
        var city = $(this).data('city');
        if($(this).hasClass("active")) {
            $(this).removeClass("active");
            $(this).parent('td').find(".bg-success").removeClass("fa-minus");
            $(this).parent('td').find(".bg-success").addClass("fa-plus");
            $(".city-loc-"+city).remove();
        }
        else {
            $(this).addClass("active");
            $(this).parent('td').find(".bg-success").removeClass("fa-plus");
            $(this).parent('td').find(".bg-success").addClass("fa-minus");
            $(this).parent('td').find(".fa-spinner").removeClass("invisible");

            /**Ajax to get locations by city */
            var curRow = $(this);
            $.ajax({
                url: "{{ url('/api/locations?city=') }}"+city,
                type: "GET",
                success: function(response) {

                    var cityLocations = '';

                    // Handle successful response
                    $.each(response[0].data, function(index, record) {
                        cityLocations += '<tr class="city-locations bg-light city-loc-'+city+'"><td class="btn btn-warning text-bold btn-sm m-1 p-2">'+record.zip+'</td><td colspan="4" class="text-md ml-3">'+record.location+'</td></tr>';
                    });

                    if(cityLocations == '') {
                        cityLocations += '<tr class="city-locations city-loc-'+city+'"><td colspan="5" class="text-md ml-3">'+response[0].message+'</td></tr>';
                    }
                    setTimeout(function(){
                        curRow.parent('td').parent('tr').after(cityLocations);
                        curRow.parent('td').find(".fa-spinner").addClass("invisible");
                    },1000);
                },
                error: function(xhr, status, error) {
                    // Handle error response
                    console.error(error);
                }
            });
        }
    });
});
</script>
@endsection
