@extends('layouts.master')

@section('title', 'Users')

@section('content')
    <section class="content">
        <div class="container-fluid">
            <a href="{{ route('admin.user.add') }}" class="btn btn-success mb-3">
                <i class="fas fa-plus"></i> Add User
            </a>
            @if(Session::has('error'))
                <div class="alert alert-danger">
                    {{ Session::get('error') }}
                </div>
            @endif
            @if(Session::has('success'))
                <div class="alert alert-success">
                    {{ Session::get('success') }}
                </div>
            @endif
            <table id="usersList" class="table table-striped table-bordered table-hover display dataTable no-footer dtr-inline">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Name</th>
                        <th>Email</th>
                        <th>Role</th>
                        <th>Status</th>
                        <th></th>
                    </tr>
                </thead>
                <tbody>
                    @if($users)
                    @foreach($users as $user)
                    <tr>
                        <td>{{ $user->id }}</td>
                        <td>{{ $user->name }}</td>
                        <td>{{ $user->email }}</td>
                        <td>{{ $user->role == 'admin' ? 'Administrator' : 'User' }}</td>
                        <td>{{ ucfirst($user->status) }}</td>
                        <td>
                            <a href="{{ route('admin.user.edit',$user->id) }}" class="btn btn-success"><i class="fas fa-edit"></i></a>
                            <a href="{{ route('admin.user.delete',$user->id) }}" class="btn btn-danger delete-user"><i class="fas fa-times"></i></a>
                        </td>
                    </tr>
                    @endforeach
                    @endif
                </tbody>
            </table>
        </div>
    </section>
@endsection

@section('pageJS')
<!-- Page Tables specific script -->
<script>
  $(function () {
    if($('#usersList').length > 0) {
        $('#usersList').DataTable({
        "paging": true,
        "lengthChange": false,
        "searching": false,
        "ordering": true,
        "info": true,
        "autoWidth": false,
        "responsive": true,
        });
    }

    $(".delete-user").on("click",function(e){
        var confirmed = confirm("Are you sure you want to delete?");
        if (!confirmed) {
            e.preventDefault();
        }
    })

  });
</script>
@endsection
